/*
 * Copyright (C) 2003 Hans Karlsson <karlsson.h@home.se>
 */


#include <kapplication.h>
#include <kfiledialog.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kconfig.h>
#include <ksimpleconfig.h>
#include <qurl.h>

#include <qfileinfo.h>
#include <qstringlist.h>

#include "karamba.h"


static const char *description = I18N_NOOP("A KDE Eye-candy Application");

static const char *version = "0.21";

static KCmdLineOptions options[] =
    {
        //    { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
        { "+file", I18N_NOOP("Theme to open."), 0 },
        { 0, 0, 0 }

    };

int main(int argc, char **argv)
{
    KAboutData about("karamba", I18N_NOOP("karamba"), version, description,
    KAboutData::License_GPL, "(C) 2003 Hans Karlsson", 0, 0, "karlsson.h@home.se");
    about.addAuthor( "Hans Karlsson", 0, "karlsson.h@home.se" );
    about.addAuthor( "Bosselut Cyril",I18N_NOOP("Karamba Replica") , "bosselut@b1project.com" );
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );

    KApplication app;
    karamba *mainWin = 0;

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

    KSimpleConfig conf("karambarc",true);
    conf.setGroup("karamba");
    QString dDir =  conf.readEntry("ThemeDir", "/usr/share/apps/karamba/themes/");
    QString dTheme =  conf.readEntry("DefaultTheme", "");


    bool OK = false;
    if(args->count() > 0)
    {
        for (int i = 0; i < (args->count()); i++)
        {
            if( args->arg(i) != "" )
            {
                QFileInfo file( args->arg(i) );
                //qDebug( file.dirPath(true) );
                if( file.exists() && !file.isDir() )
                {
                    //qDebug( "File exists" );
                    mainWin = new karamba( ( args->arg(i) ) );
                    mainWin->show();
                    OK = true;
                }
            }
        }

        //app.setMainWidget( mainWin );
        int ret = 0;
        if( OK )
            ret = app.exec();
        return ret;
    }
    else if(dTheme != ""){
      QUrl url(dTheme); //make QUrl from QString
      QString dir = url.dirPath (); //resolve the absolute path
      QString fn = (dir == ".")?dDir + "/" + dTheme:dTheme; //verify if the theme is in default dir
      QFileInfo file( fn );
      if( file.exists() && !file.isDir() ){ //verify if theme exist
        mainWin = new karamba( fn );
        mainWin->show();
        OK = true;
      }
      int ret = 0;
      if( OK ){
          ret = app.exec();
      }
      return ret;
    }
    else
    {
        QStringList fileNames;
        fileNames = KFileDialog::getOpenFileNames(dDir, "*.theme", 0, "Open configurations");
        for ( QStringList::Iterator it = fileNames.begin(); it != fileNames.end(); ++it )
        {
            QFileInfo file( *it );
            if( file.exists() && !file.isDir() )
            {
                mainWin = new karamba( *it );
                mainWin->show();
                OK = true;
            }
        }
        int ret = 0;
        if( OK ){
            ret = app.exec();
        }
        return ret;
    }

    args->clear();
    return 0;



}
